==> hive-exec-1.1.1-sources.jar: org/apache/hadoop/hive/ql/exec/spark/HiveReduceFunction.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.spark;

import org.apache.hadoop.hive.ql.io.HiveKey;
import org.apache.hadoop.io.BytesWritable;

import scala.Tuple2;

import java.util.Iterator;

public class HiveReduceFunction extends HivePairFlatMapFunction<
  Iterator<Tuple2<HiveKey, Iterable<BytesWritable>>>, HiveKey, BytesWritable> {

  private static final long serialVersionUID = 1L;

  public HiveReduceFunction(byte[] buffer, SparkReporter sparkReporter) {
    super(buffer, sparkReporter);
  }

  @SuppressWarnings("unchecked")
  @Override
  public Iterable<Tuple2<HiveKey, BytesWritable>>
  call(Iterator<Tuple2<HiveKey, Iterable<BytesWritable>>> it) throws Exception {
    initJobConf();

    SparkReduceRecordHandler reducerRecordhandler = new SparkReduceRecordHandler();
    HiveReduceFunctionResultList result =
        new HiveReduceFunctionResultList(jobConf, it, reducerRecordhandler);
    reducerRecordhandler.init(jobConf, result, sparkReporter);

    return result;
  }

  @Override
  protected boolean isMap() {
    return false;
  }
}

==> hive-exec-2.3.8-sources.jar: org/apache/hadoop/hive/ql/exec/spark/HiveReduceFunction.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.spark;

import java.util.Iterator;

import org.apache.hadoop.hive.ql.io.HiveKey;
import org.apache.hadoop.io.BytesWritable;

import scala.Tuple2;

public class HiveReduceFunction<V> extends HivePairFlatMapFunction<
  Iterator<Tuple2<HiveKey, V>>, HiveKey, BytesWritable> {

  private static final long serialVersionUID = 1L;

  public HiveReduceFunction(byte[] buffer, SparkReporter sparkReporter) {
    super(buffer, sparkReporter);
  }

  @SuppressWarnings("unchecked")
  @Override
  public Iterator<Tuple2<HiveKey, BytesWritable>>
  call(Iterator<Tuple2<HiveKey, V>> it) throws Exception {
    initJobConf();

    SparkReduceRecordHandler reducerRecordhandler = new SparkReduceRecordHandler();
    HiveReduceFunctionResultList<V> result =
        new HiveReduceFunctionResultList<V>(it, reducerRecordhandler);
    reducerRecordhandler.init(jobConf, result, sparkReporter);

    return result;
  }

  @Override
  protected boolean isMap() {
    return false;
  }
}
